@@ -3,7 +3,8 @@ from .externals.command import Command
 
 from . import const,i18n_util,cli_project,cli_oss
 from .action import login, config, info, cluster, job, cluster_create, cluster_delete, cluster_update, instance_type \
-    , job_delete, job_restart, job_stop, job_update, job_create, log_fetch, job_submit,checker
+    , job_delete, job_restart, job_stop, job_update, job_create, log_fetch, job_submit,checker\
+    ,image,image_create,image_delete
 
 import os
 
@@ -76,18 +77,45 @@ class Cli:
 
 
 
+
+
+
         # instance type
-        cmd_instance_type = Command('instance_type', alias=['it','t'],
+        cmd_instance_type = Command('instance_type', alias=['it', 't'],
                                     description=MSG['instance_type']['description'],
                                     usage='''Usage: %s instance_type|it|t [option]
 
-    Examples:
+        Examples:
 
-        1. %s t ''' % (COMMAND, CMD),
+            1. %s it ''' % (COMMAND, CMD),
                                     spliter='\n    -----%s---------------------------' % blue('query, show'),
                                     func=instance_type.list)
         self.program.action(cmd_instance_type)
 
+
+
+
+
+        # images
+        cmd_images = Command('image', alias=['img','i'],
+                               arguments=['imageId'],
+                               description=MSG['image']['description'],
+                               usage='''Usage: %s image|img|i [imageId|No.] [option]
+
+        Examples:
+
+            list images:
+              1. %s i
+
+            get cluster info:
+              1. %s i img-6ki4fsea5ldlvsupbrk01q
+              2. %s i 1''' % (COMMAND, CMD, CMD, CMD),
+                               func=image.all)
+        self.program.action(cmd_images)
+
+
+
+
         ####################################
         ####################################
         ########################################
@@ -176,6 +204,43 @@ class Cli:
         cmd_log.option('-o, --stdout', MSG['log']['option']['stdout'])
         self.program.action(cmd_log)
 
+        ##################################################
+
+        # create image
+        cmd_create_image = Command('create_image', alias=['ci'],
+                                     description=MSG['create_image']['description'],
+                                     arguments=['imageName','ecsImageId'],
+                                     usage='''Usage: %s create_image|ci [option] <imageName> <ecsImageId>
+
+            Examples:
+
+                1. %s ci myimage1 m-xxsxxx
+                2. %s ci myimage1 m-xxsxxx  -p Linux -d 'this is description' ''' % (COMMAND, CMD, CMD),
+                                     spliter='\n    -----%s----------------' % blue('create, update, delete'),
+                                     func=image_create.create_image)
+        cmd_create_image.option("-p, --platform [platform]", MSG['create_image']['option']['platform'],
+                                  resolve=image_create.trans_platform)
+        cmd_create_image.option("-d, --description [description]",
+                                  MSG['create_image']['option']['description'])
+        self.program.action(cmd_create_image)
+
+
+        # delete image
+        cmd_del_image = Command('delete_image', alias=['di'],
+                                  arguments=['imageId'],
+                                  description=MSG['delete_image']['description'],
+                                  usage='''Usage: %s delete_image|di [imageId,imageId2,imageId3...] [option]
+
+            Examples:
+
+                1. %s di img-idxxx1                # delete image with imageId
+                2. %s di img-idxxx1,img-idxxx2 -y  # delete images in silent mode''' % (COMMAND, CMD, CMD),
+                                  func=image_delete.del_image)
+        cmd_del_image.option("-y, --yes", MSG['delete_image']['option']['yes'])
+        self.program.action(cmd_del_image)
+
+
+
         ##################################################
 
         # create cluster
@@ -190,7 +255,8 @@ class Cli:
         2. %s cc cluster2 -n 3
         3. %s cc cluster2 -i %s -t %s -n 1 -d 'this is description' -u key1:value1,k2:v2''' % (
                                      COMMAND, CMD, CMD,CMD, IMG_ID, INS_TYPE),
-                                     spliter='\n    -----%s----------------' % blue('create, update, delete'),
+                                     spliter=' ',
+                                    # spliter='\n    -----%s----------------' % blue('create, update, delete'),
                                      func=cluster_create.create_cluster)
         cmd_create_cluster.option("-i, --image [imageId]", MSG['create_cluster']['option']['image'],
                                   resolve=cluster_create.trans_image)
