@@ -7,21 +7,21 @@ CMD = 'bcs'
 
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
-VERSION = '1.2.10'
+VERSION = '1.2.12'
 
 
 IT = {
     'cn-qingdao': {
         'data': [
             {'cpu': 4, 'memory': 8, 'name': 'ecs.s3.large'},
-            {'cpu': 4, 'memory': 16, 'name': 'ecs.m1.medium'},
-            {'cpu': 4, 'memory': 32, 'name': 'ecs.m2.medium'},
+            #{'cpu': 4, 'memory': 16, 'name': 'ecs.m1.medium'},
+            #{'cpu': 4, 'memory': 32, 'name': 'ecs.m2.medium'},
             {'cpu': 8, 'memory': 16, 'name': 'ecs.c1.large'},
-            {'cpu': 8, 'memory': 32, 'name': 'ecs.m1.xlarge'},
-            {'cpu': 8, 'memory': 64, 'name': 'ecs.m2.xlarge'},
-            {'cpu': 16, 'memory': 16, 'name': 'ecs.c2.medium'},
+            #{'cpu': 8, 'memory': 32, 'name': 'ecs.m1.xlarge'},
+            #{'cpu': 8, 'memory': 64, 'name': 'ecs.m2.xlarge'},
+            #{'cpu': 16, 'memory': 16, 'name': 'ecs.c2.medium'},
             {'cpu': 16, 'memory': 32, 'name': 'ecs.c2.large'},
-            {'cpu': 16, 'memory': 64, 'name': 'ecs.c2.xlarge'}
+            #{'cpu': 16, 'memory': 64, 'name': 'ecs.c2.xlarge'}
         ],
         'default': 'ecs.s3.large'
     },
@@ -44,6 +44,14 @@ IT = {
             {'cpu': 16, 'memory': 32, 'name': 'bcs.a2.3xlarge'}
         ],
         'default': 'bcs.a2.large'
+    },
+    'cn-hangzhou': {
+        'data': [
+            {'cpu': 4, 'memory': 8, 'name': 'bcs.a2.large'},
+            {'cpu': 8, 'memory': 16, 'name': 'bcs.a2.xlarge'},
+            {'cpu': 16, 'memory': 32, 'name': 'bcs.a2.3xlarge'}
+        ],
+        'default': 'bcs.a2.large'
     }
 }
 
@@ -61,6 +69,10 @@ IMG = {
     'cn-beijing': {
         'data': [],
         'default': 'm-251on8h21'
+    },
+    'cn-hangzhou': {
+        'data': [],
+        'default': 'm-23emxj6rq'
     }
 }
 
