@@ -2,9 +2,33 @@
 # -*- coding: UTF-8 -*-
 import json
 import os
-from ..util import client,it
-from terminal import white,blue
+from ..util import client,it,result_cache
+from terminal import yellow,blue
 from ..const import *
+import re
+
+
+def parse_id_arr(arr, type='jobs'):
+    t=[]
+    arr = _parse_shot_id(arr)
+
+    print(arr)
+
+    for item in arr:
+        id = result_cache.get(item, type)
+        t.append(id)
+    return t
+
+def _parse_shot_id(arr):
+    t=[]
+    for k in arr:
+        if re.match(r"^\d+\-\d+$",k):
+            (a,b) = k.split('-')
+            t = t + range(int(a),int(b)+1)
+        else:
+            t.append(k)
+    return t
+
 
 # 检查是否在project目录下运行
 def check_is_job_project():
@@ -25,7 +49,7 @@ def get_cluster_str(task_desc):
     if task_desc.get('ClusterId'):
         return task_desc.get('ClusterId')
     else:
-        return "img=%s:type=%s" % (task_desc['AutoCluster']['ECSImageId']or task_desc['AutoCluster']['ImageId'],task_desc['AutoCluster']['InstanceType'])
+        return "img=%s:type=%s" % (task_desc['AutoCluster']['ECSImageId'] or task_desc['AutoCluster']['ImageId'], task_desc['AutoCluster']['InstanceType'])
 
 
 def parse_cluster_cfg(s=None):
@@ -47,15 +71,24 @@ def parse_cluster_cfg(s=None):
 
             [k,v]=item.split('=',1)
             if k=='img':
-                m['ECSImageId']=v
+                if v.startswith('img-'):
+                    m['ImageId']=v
+                elif v.startswith('m-'):
+                    m['ECSImageId']=v
+                else:
+                    raise Exception('Invalid imageId: %s' % v)
             if k=='type':
                 m['InstanceType']=v
 
-        m['ECSImageId']= m['ECSImageId'] if  m.get('ECSImageId') else IMG_ID
-        m['InstanceType']= m['InstanceType'] if  m.get('InstanceType') else INS_TYPE
+
+        if not m.get('ImageId') and not m.get('ECSImageId'):
+            m['ECSImageId']= IMG_ID
+
+        if not m.get('InstanceType'):
+            m['InstanceType']= INS_TYPE
 
         if not it.get_ins_type_map().get(m['InstanceType']):
-            raise Exception('Invalid type(InstanceType), type "%s it" for more' % CMD)
+            print(yellow("Warning: '%s' may not be valid, type '%s it' for more" % (m['InstanceType'], CMD)))
 
         #print(white('using AuthCluster: %s' % m))
         return {'AutoCluster':m,'ClusterId':''}
@@ -84,6 +117,9 @@ def trans_mount(s):
             v = item[ind+1:]
         else:
             [k,v]=item.split(':',1)
+
+        if len(v)==1 and str.isalpha(v):
+            v = v + ':'
         mount[k]=v
     return mount
 
@@ -137,3 +173,32 @@ def print_inst_result(result):
     print('%s : %s' % (blue('Detail'), result.Detail))
 
 
+
+def trans_disk(disk):
+
+    try:
+        infos = disk.split(',')
+
+        result = {}
+
+        for info in infos:
+
+            if info.startswith('system:'):
+                (name, type, size) = info.split(':')
+                result['SystemDisk'] = {
+                    'Type': type, 'Size': int(size)
+                }
+            elif info.startswith('data:'):
+                (name, type2, size2, mount_point) = info.split(':')
+                result['DataDisk'] = {
+                    'Type': type2, 'Size': int(size2), 'MountPoint': mount_point
+                }
+            else:
+                raise Exception('Invalid disk format')
+
+        return result
+
+    except BaseException as e:
+        raise Exception(
+            'Invalid disk format, it should like this: --disk system:ephemeral:40,data:cloud:500:/home/disk, append -h for more')
+
